---
url: https://www.normattiva.it/uri-res/N2Ls?urn:nir:stato:legge:2003-11-24;326
url_xml: https://www.normattiva.it/do/atto/caricaAKN?dataGU=20031125&codiceRedaz=003G0358&dataVigenza=20251104
dataGU: 20031125
codiceRedaz: 003G0358
dataVigenza: 20251104
---

# Conversione in legge, con modificazioni, del decreto-legge 30 settembre 2003, n. 269, recante disposizioni urgenti per favorire lo sviluppo e per la correzione dell'andamento dei conti pubblici.

La Camera dei deputati ed il Senato della Repubblica hanno approvato;

IL PRESIDENTE DELLA REPUBBLICA

Promulga la seguente legge:

## Art. 1.

1. Il decreto-legge 30 settembre 2003, n. 269, recante disposizioni urgenti per favorire lo sviluppo e per la correzione dell'andamento dei conti pubblici, e' convertito in legge con le modificazioni riportate in allegato alla presente legge.

2. La presente legge entra in vigore il giorno successivo a quello della sua pubblicazione nella Gazzetta Ufficiale.

